=======================================
template me - Manager for templates 
=======================================

Console programs to make new project in defined language

.. image:: https://img.shields.io/badge/author-Rafa%C5%82%20Kobel-blue.svg
    :target: https://rafyco.pl

.. image:: https://img.shields.io/travis/rafyco/templateme.svg
   :target: https://travis-ci.org/rafyco/templateme

.. image:: https://img.shields.io/pypi/v/templateme.svg
   :target: https://pypi.python.org/pypi/templateme/

.. image:: https://img.shields.io/github/license/rafyco/templateme.svg
   :target: https://www.gnu.org/licenses/gpl.html


Instalation
-----------

PyPi
~~~~

::

    sudo pip3 install templateme

setup.py
~~~~~~~~

::

    sudo python3 setup.py install

Usage
-----

To invoke program type in your console:

::

    templateme -t <template_name> -p <your_project_name>

or try:

::

    templateme --help


Unit test
---------

For testing module write:

::

    python3 setup.py test

Author
------

Rafal Kobel rafalkobel@rafyco.pl

